@@ -1,10 +1,26 @@
 from __future__ import absolute_import
 
+import signal
+import sys
+
 from time import time
 
 from .exceptions import RestartFreqExceeded
 
 
+def _shutdown_cleanup(signum, frame):
+    sys.exit(-(256 - signum))
+
+
+def reset_signals(handler=_shutdown_cleanup):
+    for i in range(signal.NSIG):
+        try:
+            if signal.getsignal(i) != signal.SIG_IGN:
+                signal.signal(i, handler)
+        except (ValueError, RuntimeError):
+            pass
+
+
 class restart_state(object):
     RestartFreqExceeded = RestartFreqExceeded
 
